@@ -1,7 +1,9 @@
 package Sah::Schema::share;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-04'; # DATE
+our $DIST = 'Sah-Schemas-Float'; # DIST
+our $VERSION = '0.007'; # VERSION
 
 our $schema = ['float', {
     summary => 'A float between 0 and 1',
@@ -21,6 +23,15 @@ _
     'x.perl.coerce_rules' => [
         'From_str::share',
     ],
+
+    examples => [
+        {value=>0, valid=>1, validated_value=>0},
+        {value=>0.5, valid=>1, validated_value=>0.5},
+        {value=>1, valid=>1, validated_value=>1},
+        {value=>1.2, valid=>1, validated_value=>0.012},
+        {value=>'1.2%', valid=>1, validated_value=>0.012},
+        {value=>'102%', valid=>0},
+    ],
 }, {}];
 
 1;
@@ -38,7 +49,53 @@ Sah::Schema::share - A float between 0 and 1
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::share (from Perl distribution Sah-Schemas-Float), released on 2019-11-29.
+This document describes version 0.007 of Sah::Schema::share (from Perl distribution Sah-Schemas-Float), released on 2020-03-04.
+
+=head1 SYNOPSIS
+
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("share*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['share*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
+Sample data:
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # INVALID
 
 =head1 DESCRIPTION
 
@@ -74,7 +131,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
